==> cloudfront-1.104.0-sources.jar: software/amazon/awscdk/services/cloudfront/ViewerCertificate.java <==
package software.amazon.awscdk.services.cloudfront;

/**
 * Viewer certificate configuration class.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.29.0 (build 41df200)", date = "2021-05-14T22:40:16.025Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudfront.$Module.class, fqn = "@aws-cdk/aws-cloudfront.ViewerCertificate")
public class ViewerCertificate extends software.amazon.jsii.JsiiObject {

    protected ViewerCertificate(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ViewerCertificate(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * Generate an AWS Certificate Manager (ACM) viewer certificate configuration.
     * <p>
     * @param certificate AWS Certificate Manager (ACM) certificate. This parameter is required.
     * @param options certificate configuration options.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudfront.ViewerCertificate fromAcmCertificate(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.certificatemanager.ICertificate certificate, final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.cloudfront.ViewerCertificateOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.cloudfront.ViewerCertificate.class, "fromAcmCertificate", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.ViewerCertificate.class), new Object[] { java.util.Objects.requireNonNull(certificate, "certificate is required"), options });
    }

    /**
     * Generate an AWS Certificate Manager (ACM) viewer certificate configuration.
     * <p>
     * @param certificate AWS Certificate Manager (ACM) certificate. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudfront.ViewerCertificate fromAcmCertificate(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.certificatemanager.ICertificate certificate) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.cloudfront.ViewerCertificate.class, "fromAcmCertificate", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.ViewerCertificate.class), new Object[] { java.util.Objects.requireNonNull(certificate, "certificate is required") });
    }

    /**
     * Generate a viewer certifcate configuration using the CloudFront default certificate (e.g. d111111abcdef8.cloudfront.net) and a {@link SecurityPolicyProtocol.TLS_V1} security policy.
     * <p>
     * @param aliases Alternative CNAME aliases You also must create a CNAME record with your DNS service to route queries. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudfront.ViewerCertificate fromCloudFrontDefaultCertificate(final @org.jetbrains.annotations.NotNull java.lang.String... aliases) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.cloudfront.ViewerCertificate.class, "fromCloudFrontDefaultCertificate", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.ViewerCertificate.class), java.util.Arrays.<Object>stream(aliases).toArray(Object[]::new));
    }

    /**
     * Generate an IAM viewer certificate configuration.
     * <p>
     * @param iamCertificateId Identifier of the IAM certificate. This parameter is required.
     * @param options certificate configuration options.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudfront.ViewerCertificate fromIamCertificate(final @org.jetbrains.annotations.NotNull java.lang.String iamCertificateId, final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.cloudfront.ViewerCertificateOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.cloudfront.ViewerCertificate.class, "fromIamCertificate", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.ViewerCertificate.class), new Object[] { java.util.Objects.requireNonNull(iamCertificateId, "iamCertificateId is required"), options });
    }

    /**
     * Generate an IAM viewer certificate configuration.
     * <p>
     * @param iamCertificateId Identifier of the IAM certificate. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudfront.ViewerCertificate fromIamCertificate(final @org.jetbrains.annotations.NotNull java.lang.String iamCertificateId) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.cloudfront.ViewerCertificate.class, "fromIamCertificate", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.ViewerCertificate.class), new Object[] { java.util.Objects.requireNonNull(iamCertificateId, "iamCertificateId is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> getAliases() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "aliases", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudfront.CfnDistribution.ViewerCertificateProperty getProps() {
        return software.amazon.jsii.Kernel.get(this, "props", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.CfnDistribution.ViewerCertificateProperty.class));
    }
}

==> cloudfront-1.173.0-sources.jar: software/amazon/awscdk/services/cloudfront/ViewerCertificate.java <==
package software.amazon.awscdk.services.cloudfront;

/**
 * Viewer certificate configuration class.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * Bucket s3BucketSource = new Bucket(this, "Bucket");
 * CloudFrontWebDistribution distribution = CloudFrontWebDistribution.Builder.create(this, "AnAmazingWebsiteProbably")
 *         .originConfigs(List.of(SourceConfiguration.builder()
 *                 .s3OriginSource(S3OriginConfig.builder().s3BucketSource(s3BucketSource).build())
 *                 .behaviors(List.of(Behavior.builder().isDefaultBehavior(true).build()))
 *                 .build()))
 *         .viewerCertificate(ViewerCertificate.fromIamCertificate("certificateId", ViewerCertificateOptions.builder()
 *                 .aliases(List.of("example.com"))
 *                 .securityPolicy(SecurityPolicyProtocol.SSL_V3) // default
 *                 .sslMethod(SSLMethod.SNI)
 *                 .build()))
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.67.0 (build 2c027f5)", date = "2022-09-16T18:50:32.998Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudfront.$Module.class, fqn = "@aws-cdk/aws-cloudfront.ViewerCertificate")
public class ViewerCertificate extends software.amazon.jsii.JsiiObject {

    protected ViewerCertificate(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ViewerCertificate(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * Generate an AWS Certificate Manager (ACM) viewer certificate configuration.
     * <p>
     * @param certificate AWS Certificate Manager (ACM) certificate. This parameter is required.
     * @param options certificate configuration options.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudfront.ViewerCertificate fromAcmCertificate(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.certificatemanager.ICertificate certificate, final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.cloudfront.ViewerCertificateOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.cloudfront.ViewerCertificate.class, "fromAcmCertificate", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.ViewerCertificate.class), new Object[] { java.util.Objects.requireNonNull(certificate, "certificate is required"), options });
    }

    /**
     * Generate an AWS Certificate Manager (ACM) viewer certificate configuration.
     * <p>
     * @param certificate AWS Certificate Manager (ACM) certificate. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudfront.ViewerCertificate fromAcmCertificate(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.certificatemanager.ICertificate certificate) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.cloudfront.ViewerCertificate.class, "fromAcmCertificate", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.ViewerCertificate.class), new Object[] { java.util.Objects.requireNonNull(certificate, "certificate is required") });
    }

    /**
     * Generate a viewer certifcate configuration using the CloudFront default certificate (e.g. d111111abcdef8.cloudfront.net) and a {@link SecurityPolicyProtocol.TLS_V1} security policy.
     * <p>
     * @param aliases Alternative CNAME aliases You also must create a CNAME record with your DNS service to route queries. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudfront.ViewerCertificate fromCloudFrontDefaultCertificate(final @org.jetbrains.annotations.NotNull java.lang.String... aliases) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.cloudfront.ViewerCertificate.class, "fromCloudFrontDefaultCertificate", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.ViewerCertificate.class), java.util.Arrays.<Object>stream(aliases).toArray(Object[]::new));
    }

    /**
     * Generate an IAM viewer certificate configuration.
     * <p>
     * @param iamCertificateId Identifier of the IAM certificate. This parameter is required.
     * @param options certificate configuration options.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudfront.ViewerCertificate fromIamCertificate(final @org.jetbrains.annotations.NotNull java.lang.String iamCertificateId, final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.cloudfront.ViewerCertificateOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.cloudfront.ViewerCertificate.class, "fromIamCertificate", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.ViewerCertificate.class), new Object[] { java.util.Objects.requireNonNull(iamCertificateId, "iamCertificateId is required"), options });
    }

    /**
     * Generate an IAM viewer certificate configuration.
     * <p>
     * @param iamCertificateId Identifier of the IAM certificate. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudfront.ViewerCertificate fromIamCertificate(final @org.jetbrains.annotations.NotNull java.lang.String iamCertificateId) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.cloudfront.ViewerCertificate.class, "fromIamCertificate", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.ViewerCertificate.class), new Object[] { java.util.Objects.requireNonNull(iamCertificateId, "iamCertificateId is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> getAliases() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "aliases", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudfront.CfnDistribution.ViewerCertificateProperty getProps() {
        return software.amazon.jsii.Kernel.get(this, "props", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.CfnDistribution.ViewerCertificateProperty.class));
    }
}
